==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Core/System.Linq.Parallel.QueryNodes/QueryStreamNode.cs <==
//
// QueryStreamNode.cs
//
// Author:
//       Jérémie "Garuma" Laval <jeremie.laval@gmail.com>
//
// Copyright (c) 2010 Jérémie "Garuma" Laval
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#if NET_4_0
using System;
using System.Threading;
using System.Threading.Tasks;
using System.Collections.Generic;

namespace System.Linq.Parallel.QueryNodes
{
	internal abstract class QueryStreamNode<T, TParent> : QueryChildNode<T, TParent>
	{
		bool isIndexed;

		internal QueryStreamNode (QueryBaseNode<TParent> parent, bool isIndexed)
			: base (parent)
		{
			this.isIndexed = isIndexed;
		}

		internal override IList<IEnumerable<T>> GetEnumerables (QueryOptions options)
		{
			if (IsIndexed)
				return GetEnumerablesIndexed (options);
			else
				return GetEnumerablesNonIndexed (options);
		}

		internal virtual IList<IEnumerable<T>> GetEnumerablesIndexed (QueryOptions options)
		{
			return null;
		}

		internal virtual IList<IEnumerable<T>> GetEnumerablesNonIndexed (QueryOptions options)
		{
			return null;
		}

		public override void Visit (INodeVisitor visitor)
		{
			visitor.Visit<T, TParent> (this);
		}

		public bool IsIndexed {
			get {
				return isIndexed;
			}
		}
	}
}
#endif

==> mono-3.0.3.tar.bz2: mono-3.0.3/mcs/class/System.Core/System.Linq.Parallel.QueryNodes/QueryStreamNode.cs <==
//
// QueryStreamNode.cs
//
// Author:
//       Jérémie "Garuma" Laval <jeremie.laval@gmail.com>
//
// Copyright (c) 2010 Jérémie "Garuma" Laval
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#if NET_4_0 || MOBILE
using System;
using System.Threading;
using System.Threading.Tasks;
using System.Collections.Generic;

namespace System.Linq.Parallel.QueryNodes
{
	internal interface QueryStreamNode : IVisitableNode {
		bool IsIndexed { get; }
	}

	internal abstract class QueryStreamNode<T, TParent> : QueryChildNode<T, TParent>, QueryStreamNode
	{
		bool isIndexed;

		internal QueryStreamNode (QueryBaseNode<TParent> parent, bool isIndexed)
			: base (parent)
		{
			this.isIndexed = isIndexed;
		}

		internal override IList<IEnumerable<T>> GetEnumerables (QueryOptions options)
		{
			if (IsIndexed)
				return GetEnumerablesIndexed (options);
			else
				return GetEnumerablesNonIndexed (options);
		}

		internal virtual IList<IEnumerable<T>> GetEnumerablesIndexed (QueryOptions options)
		{
			return null;
		}

		internal virtual IList<IEnumerable<T>> GetEnumerablesNonIndexed (QueryOptions options)
		{
			return null;
		}

		public override void Visit (INodeVisitor visitor)
		{
			visitor.Visit ((QueryStreamNode)this);
		}

		public bool IsIndexed {
			get {
				return isIndexed;
			}
		}
	}
}
#endif
